# wxMiniStore

一个基于原生小程序的mini全局状态管理库，五行代码即可引入。
* 全局状态state支持所有Page和Component，状态完全同步，并提供api，自动diff状态并更新。
* 周期监听pageLisener能监听所有页面的onLoad，onShow等周期事件。
* 全局事件methods，全局可用的方法。
* 适合原生小程序，可以随时引入，不影响原有的业务，拓展性强。


## <div id="start">快速开始</div>

### 1. 引入
目前有两种引入方式：
#### npm
 首先你需要npm init 在项目目录下生成 package.json后，再进行安装。
 ``` cmd
 npm init
 npm install wxministore -S
 ```
 然后在微信小程序右上角详情中勾选 `使用npm模块`。  
 接着选择左上角 工具-构建 npm。 
 这样你就可以在项目中导入了。
 
 ```js
//app.js中
import Store from 'wxministore';
//或者 const Store = require('wxministore');
App({
})
```
#### clone
如果不太熟悉npm没关系，你可以将[git项目](https://github.com/yx675258207/wxMiniStore)中util下的store.js复制到你的项目中，并在`app.js第一行`引入：
```js
//app.js中
import Store from './util/store.js';
//或者 const Store = require('./util/store.js');
App({
})
```
### <div id="state">2. 实例化一个全局状态 state</div>
Store 允许传一个参数，类型为Object，全局状态写入对象state中，读取请使用store.$state。
```js 
let store = new Store({
  //。
  state: {
    msg: '这是一个全局状态'
  }
})
console.log(store.$state.msg); //这是一个全局状态
App({
})
```
### 3.在App中注入store
这么做是为了在其他页面中使用store。
```js
App({
  onLaunch: function () {

  },
  store: store
})
```
### 4.页面上使用
在所有wxml中，可使用$state.x。
其中$state为全局状态的容器，里面包含了所有的全局状态。
```html
  <view>{{$state.user.name}}：{{$state.msg}}</view>
```
显示为 李四：这是一个全局状态。

如果在template文件中使用，需在属性data中引用$state
```html
  <!-- 这是一个template -->
  <template name="t1">
    <view>{{$state.msg}}</view>
  </template>

<!-- 这是引用位置 -->
  <template is="t1" data="{{$state,arg1,arg2}}" />
<!--   相当于<template is="t1" data="{{$state:$state,arg1:arg1,arg2:arg2}}" /> -->
```
在版本1.2.1+建议使用App.Page和 App.Component创建页面和组件，当然也不是必须。详情查看[nonWritable](#nonWritable)
``` js
// 没问题
Page({
  //...
})

// 更好
App.Page({
  //...
})

```


### 5.如何修改状态
js中使用app中的store来进行操作状态。具体参见下面api说明。

``` js
const app = getApp()
App.Page({
  data: {

  },
  onLoad: function () {
    //所有wxml中的$state.msg会同步更新
    app.store.setState({
       msg: "我被修改了，呜呜..."
    });
  }
});

```